.. image:: https://img.shields.io/pypi/v/tox.svg
   :target: https://pypi.org/project/tox/
.. image:: https://img.shields.io/pypi/pyversions/tox.svg
  :target: https://pypi.org/project/tox/
.. image:: https://travis-ci.org/tox-dev/tox.svg?branch=master
    :target: https://travis-ci.org/tox-dev/tox
.. image:: https://img.shields.io/appveyor/ci/RonnyPfannschmidt/tox/master.svg
    :target: https://ci.appveyor.com/project/RonnyPfannschmidt/tox
.. image:: https://codecov.io/gh/tox-dev/tox/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/tox-dev/tox
.. image:: https://readthedocs.org/projects/tox/badge/?version=latest
  :target: http://tox.readthedocs.io/en/latest/?badge=latest
  :alt: Documentation Status

tox automation project
======================

**vision: standardize testing in Python**

tox aims to automate and standardize testing in Python. It is part of a larger vision of easing the packaging, testing and release process of Python software.

What is tox?
============

tox is a generic virtualenv management and test command line tool you can use for:

* checking your package installs correctly with different Python versions and
  interpreters

* running your tests in each of the environments, configuring your test tool of choice

* acting as a frontend to Continuous Integration servers, greatly
  reducing boilerplate and merging CI and shell-based testing.

For more information and the repository please see:

- home and docs: https://tox.readthedocs.org

- repository: https://github.com/tox-dev/tox

Code coverage of latest master build
====================================

.. image:: https://codecov.io/gh/tox-dev/tox/branch/master/graphs/sunburst.svg
  :target: https://codecov.io/gh/tox-dev/tox/branch/master
